==> final-form-4.20.2.jar: META-INF/resources/webjars/final-form/4.20.2/README.md <==
[<img src="form-nerd-logo.png" align="left"/>](https://formnerd.co/final-form-readme) **You build great forms, but do you know HOW users use your forms? [Find out with Form Nerd!](https://formnerd.co/final-form-readme) Professional analytics from the creator of Final Form.**

---

💰 **Hey there! Do you fancy yourself a javascript expert? [Take this quiz](https://triplebyte.com/a/V6j0KPS/ff) and get offers from top tech companies!** 💰

---

# 🏁 Final Form

[![Final Form](banner.png)](https://final-form.org)

[![Backers on Open Collective](https://opencollective.com/final-form/backers/badge.svg)](#backers)
[![Sponsors on Open Collective](https://opencollective.com/final-form/sponsors/badge.svg)](#sponsors)
[![NPM Version](https://img.shields.io/npm/v/final-form.svg?style=flat)](https://www.npmjs.com/package/final-form)
[![NPM Downloads](https://img.shields.io/npm/dm/final-form.svg?style=flat)](https://npm-stat.com/charts.html?package=final-form)
[![Build Status](https://travis-ci.org/final-form/final-form.svg?branch=master)](https://travis-ci.org/final-form/final-form)
[![codecov.io](https://codecov.io/gh/final-form/final-form/branch/master/graph/badge.svg)](https://codecov.io/gh/final-form/final-form)
[![styled with prettier](https://img.shields.io/badge/styled_with-prettier-ff69b4.svg)](https://github.com/prettier/prettier)

✅ **Zero** dependencies

✅ Framework agnostic

✅ Opt-in subscriptions - only update on the state you need!

✅ 💥 [**5.1k gzipped**](https://bundlephobia.com/result?p=final-form) 💥

---

[<img align="right" src="docs/sencha.svg" height="100"/>](https://www.sencha.com/)

### Final Form is sponsored by [Sencha](https://www.sencha.com/).

Comprehensive JS framework and UI components for building enterprise-grade web apps.

---

## 💬 [Give Feedback on Final Form](https://goo.gl/forms/dxdfxKNy64DLb99z2) 💬

In the interest of making 🏁 Final Form the best library it can be, we'd love your thoughts and feedback.

[Take a quick survey](https://goo.gl/forms/dxdfxKNy64DLb99z2).

---

## [Get Started](https://final-form.org/docs/final-form/getting-started)

## [Philosophy](https://final-form.org/docs/final-form/philosophy)

## [Examples](https://final-form.org/docs/final-form/examples)

## [API](https://final-form.org/docs/final-form/api)

## [Companion Libraries](https://final-form.org/docs/final-form/companion-libraries)

## [Who's using Final Form?](https://final-form.org/users)

<img src="https://static.scarf.sh/a.png?x-pxid=40db3a4c-1187-4b9e-b363-c059774fe5e1" />

==> final-form-4.20.9.jar: META-INF/resources/webjars/final-form/4.20.9/README.md <==
[<img src="form-nerd-logo.png" align="left"/>](https://formnerd.co/final-form-readme) **You build great forms, but do you know HOW users use your forms? [Find out with Form Nerd!](https://formnerd.co/final-form-readme) Professional analytics from the creator of Final Form.**

---

💰 **Hey there! Do you fancy yourself a javascript expert? [Take this quiz](https://triplebyte.com/a/V6j0KPS/ff) and get offers from top tech companies!** 💰

---

# 🏁 Final Form

[![Final Form](banner.png)](https://final-form.org)

[![Backers on Open Collective](https://opencollective.com/final-form/backers/badge.svg)](#backers)
[![Sponsors on Open Collective](https://opencollective.com/final-form/sponsors/badge.svg)](#sponsors)
[![NPM Version](https://img.shields.io/npm/v/final-form.svg?style=flat)](https://www.npmjs.com/package/final-form)
[![NPM Downloads](https://img.shields.io/npm/dm/final-form.svg?style=flat)](https://npm-stat.com/charts.html?package=final-form)
[![Build Status](https://travis-ci.org/final-form/final-form.svg?branch=main)](https://travis-ci.org/final-form/final-form)
[![codecov.io](https://codecov.io/gh/final-form/final-form/branch/main/graph/badge.svg)](https://codecov.io/gh/final-form/final-form)
[![styled with prettier](https://img.shields.io/badge/styled_with-prettier-ff69b4.svg)](https://github.com/prettier/prettier)

✅ **Zero** dependencies

✅ Framework agnostic

✅ Opt-in subscriptions - only update on the state you need!

✅ 💥 [**5.1k gzipped**](https://bundlephobia.com/result?p=final-form) 💥

---

[<img align="right" src="docs/sencha.svg" height="100"/>](https://www.sencha.com/)

### Final Form is sponsored by [Sencha](https://www.sencha.com/).

Comprehensive JS framework and UI components for building enterprise-grade web apps.

---

## 💬 [Give Feedback on Final Form](https://goo.gl/forms/dxdfxKNy64DLb99z2) 💬

In the interest of making 🏁 Final Form the best library it can be, we'd love your thoughts and feedback.

[Take a quick survey](https://goo.gl/forms/dxdfxKNy64DLb99z2).

---

## [Get Started](https://final-form.org/docs/final-form/getting-started)

## [Philosophy](https://final-form.org/docs/final-form/philosophy)

## [Examples](https://final-form.org/docs/final-form/examples)

## [API](https://final-form.org/docs/final-form/api)

## [Companion Libraries](https://final-form.org/docs/final-form/companion-libraries)

## [Who's using Final Form?](https://final-form.org/users)

<img src="https://static.scarf.sh/a.png?x-pxid=40db3a4c-1187-4b9e-b363-c059774fe5e1" />
